@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -37,7 +37,6 @@ _ = glocale.translation.gettext
 from .tabbeddoc import *
 from ...const import PROGRAM_NAME, VERSION
 from ...errors import ReportError
-from ...constfunc import cuni
 
 #-------------------------------------------------------------------------
 #
@@ -342,7 +341,7 @@ class ODSTab(TabbedDoc):
         except:
             raise ReportError(_("Could not create %s") % self.content_xml)
 
-        self.f = open(self.content_xml,"w")
+        self.f = open(self.content_xml,"w", encoding='utf-8')
         self.f.write(
             '<?xml version="1.0" encoding="UTF-8"?>\n' +
             '<office:document-content ' +
@@ -389,7 +388,7 @@ class ODSTab(TabbedDoc):
             text = text.replace('>','&gt;')
             text = text.replace('\t','<text:tab-stop/>')
             text = text.replace('\n','<text:line-break/>')
-            self.f.write(cuni(text))
+            self.f.write(str(text))
 
         self.f.write('</text:p>\n')
         self.f.write('</table:table-cell>\n')
