@@ -17,13 +17,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
 Module that implements the gramplet bar fuctionality.
 """
-from __future__ import unicode_literals
 
 #-------------------------------------------------------------------------
 #
@@ -42,11 +41,7 @@ from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.gettext
 import time
 import os
-import sys
-if sys.version_info[0] < 3:
-    import ConfigParser as configparser
-else:
-    import configparser
+import configparser
 import io
 
 #-------------------------------------------------------------------------
@@ -112,7 +107,8 @@ class GrampletBar(Gtk.Notebook):
         self.set_scrollable(True)
 
         book_button = Gtk.Button()
-        box = Gtk.VBox() # Arrow is too small unless in a Vbox
+        # Arrow is too small unless in a box
+        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         arrow = Gtk.Arrow(arrow_type=Gtk.ArrowType.DOWN, 
                                     shadow_type=Gtk.ShadowType.NONE)
         arrow.show()
@@ -345,7 +341,7 @@ class GrampletBar(Gtk.Notebook):
         tab_label.show()
         msg = _('Select the down arrow on the right corner for adding, removing or restoring gramplets.')
         content = Gtk.Label(label=msg)
-        content.set_alignment(0, 0)
+        content.set_halign(Gtk.Align.START)
         content.set_line_wrap(True)
         content.set_size_request(150, -1)
         content.show()
@@ -360,7 +356,8 @@ class GrampletBar(Gtk.Notebook):
         height = min(int(self.uistate.screen_height() * 0.20), 400)
         gramplet.set_size_request(width, height)
 
-        page_num = self.append_page(gramplet, Gtk.Label(label=''))
+        label = self.__create_tab_label(gramplet)
+        page_num = self.append_page(gramplet, label)
         return page_num
 
     def __create_tab_label(self, gramplet):
@@ -615,13 +612,13 @@ class DetachedWindow(ManagedWindow):
                                              self.title)
         self.set_window(Gtk.Dialog("", gramplet.uistate.window,
                                    Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                   (Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)),
+                                   (_('_Close'), Gtk.ResponseType.CLOSE)),
                         None,
                         self.title)
         self.window.move(x_pos, y_pos)
-        self.window.set_size_request(gramplet.detached_width,
+        self.window.set_default_size(gramplet.detached_width,
                                      gramplet.detached_height)
-        self.window.add_button(Gtk.STOCK_HELP, Gtk.ResponseType.HELP)
+        self.window.add_button(_('_Help'), Gtk.ResponseType.HELP)
         self.window.connect('response', self.handle_response)
 
         self.notebook = Gtk.Notebook()
@@ -643,7 +640,7 @@ class DetachedWindow(ManagedWindow):
         """
         Callback for taking care of button clicks.
         """
-        if response in [Gtk.ResponseType.CLOSE, Gtk.STOCK_CLOSE]:
+        if response == Gtk.ResponseType.CLOSE:
             self.close()
         elif response == Gtk.ResponseType.HELP:
             # translated name:
@@ -690,12 +687,12 @@ class DetachedWindow(ManagedWindow):
 # TabLabel class
 #
 #-------------------------------------------------------------------------
-class TabLabel(Gtk.HBox):
+class TabLabel(Gtk.Box):
     """
     Create a tab label consisting of a label and a close button.
     """
     def __init__(self, gramplet, callback):
-        Gtk.HBox.__init__(self)
+        Gtk.Box.__init__(self)
         
         self.text = gramplet.title
         self.set_spacing(4)
@@ -706,7 +703,7 @@ class TabLabel(Gtk.HBox):
 
         self.closebtn = Gtk.Button()
         image = Gtk.Image()
-        image.set_from_stock(Gtk.STOCK_CLOSE, Gtk.IconSize.MENU)
+        image.set_from_icon_name('window-close', Gtk.IconSize.MENU)
         self.closebtn.connect("clicked", callback, gramplet)
         self.closebtn.set_image(image)
         self.closebtn.set_relief(Gtk.ReliefStyle.NONE)
@@ -733,10 +730,18 @@ class TabLabel(Gtk.HBox):
         else:
             self.closebtn.hide()
 
-def cb_menu_position(menu, button):
+def cb_menu_position(*args):
     """
     Determine the position of the popup menu.
     """
+    # takes two argument: menu, button
+    if len(args) == 2:
+        menu = args[0]
+        button = args[1]
+    # broken introspection can't handle MenuPositionFunc annotations corectly
+    else:
+        menu = args[0]
+        button = args[3]
     ret_val, x_pos, y_pos = button.get_window().get_origin()
     x_pos += button.get_allocation().x
     y_pos += button.get_allocation().y + button.get_allocation().height
