@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -33,7 +33,7 @@ _ = glocale.translation.gettext
 import operator
 from gi.repository import Gtk
 from math import *
-import cgi
+from html import escape
 
 #-------------------------------------------------------------------------
 #
@@ -52,6 +52,7 @@ from gramps.gen.lib import EventRoleType, EventType
 from gramps.gen.config import config
 from gramps.gen.datehandler import displayer, get_date
 from gramps.gen.display.name import displayer as _nd
+from gramps.gen.display.place import displayer as _pd
 from gramps.gen.utils.place import conv_lat_lon
 from gramps.gui.views.navigationview import NavigationView
 from gramps.gui.views.bookmarks import PersonBookmarks
@@ -122,6 +123,7 @@ class GeoClose(GeoGraphyView):
         ('geography.lock', False),
         ('geography.center-lat', 0.0),
         ('geography.center-lon', 0.0),
+        ('geography.use-keypad', True),
 
         ('geography.map_service', constants.OPENSTREETMAP),
         ('geography.max_places', 5000),
@@ -230,7 +232,7 @@ class GeoClose(GeoGraphyView):
             self._createmap(self.refperson, color, self.place_list_ref, True)
             if self.refperson_bookmark is None:
                 self.refperson_bookmark = self.refperson.get_handle()
-                self.add_bookmark(None, self.refperson_bookmark)
+                self.add_bookmark_from_popup(None, self.refperson_bookmark)
         else:
             self.message_layer.add_message(_("You must choose one reference person."))
             self.message_layer.add_message(_("Go to the person view and select "
@@ -247,11 +249,11 @@ class GeoClose(GeoGraphyView):
         if birth and birth.get_type() != EventType.BIRTH:
             sdate = get_date(birth)
             if sdate:
-                bdate  = "<i>%s</i>" % cgi.escape(sdate)
+                bdate = "<i>%s</i>" % escape(sdate)
             else:
                 bdate = ""
         elif birth:
-            bdate = cgi.escape(get_date(birth))
+            bdate = escape(get_date(birth))
         else:
             bdate = ""
         return bdate
@@ -264,11 +266,11 @@ class GeoClose(GeoGraphyView):
         if death and death.get_type() != EventType.DEATH:
             sdate = get_date(death)
             if sdate:
-                ddate  = "<i>%s</i>" % cgi.escape(sdate)
+                ddate = "<i>%s</i>" % escape(sdate)
             else:
                 ddate = ""
         elif death:
-            ddate  = cgi.escape(get_date(death))
+            ddate = escape(get_date(death))
         else:
             ddate = ""
         return ddate
@@ -390,7 +392,7 @@ class GeoClose(GeoGraphyView):
                         latitude = place.get_latitude()
                         latitude, longitude = conv_lat_lon(latitude,
                                                            longitude, "D.D8")
-                        descr = place.get_title()
+                        descr = _pd.display(dbstate.db, place)
                         evt = EventType(event.get_type())
                         descr1 = _("%(eventtype)s : %(name)s") % {
                                         'eventtype': evt,
@@ -442,7 +444,7 @@ class GeoClose(GeoGraphyView):
                                         latitude = place.get_latitude()
                                         latitude, longitude = conv_lat_lon(
                                                   latitude, longitude, "D.D8")
-                                        descr = place.get_title()
+                                        descr = _pd.display(dbstate.db, place)
                                         evt = EventType(
                                                   event.get_type())
                                         eyear = str("%04d" % event.get_date_object().to_calendar(self.cal).get_year()) + \
@@ -533,9 +535,7 @@ class GeoClose(GeoGraphyView):
                                    event, lat, lon, prevmark)
                     itemoption.append(center)
                     menu.show()
-                    menu.popup(None, None,
-                               lambda menu, data: (event.get_root_coords()[0],
-                                                   event.get_root_coords()[1], True),
+                    menu.popup(None, None, None,
                                None, event.button, event.time)
         return 0
 
@@ -564,11 +564,11 @@ class GeoClose(GeoGraphyView):
         Add specific entry to the preference menu.
         Must be done in the associated view.
         """
-        table = Gtk.Table(n_rows=2, n_columns=2)
-        table.set_border_width(12)
-        table.set_col_spacings(6)
-        table.set_row_spacings(6)
-        configdialog.add_text(table,
+        grid = Gtk.Grid()
+        grid.set_border_width(12)
+        grid.set_column_spacing(6)
+        grid.set_row_spacing(6)
+        configdialog.add_text(grid,
                 _('The meeting zone probability radius.\n'
                   'The colored zone is approximative.\n'
                   'The meeting zone is only shown for the reference person.\n'
@@ -576,11 +576,11 @@ class GeoClose(GeoGraphyView):
                   'The value 1 means about 4.6 miles or 7.5 kms.\n'
                   'The value is in tenth of degree.'),
                 1, line_wrap=False)
-        self.config_meeting_slider = configdialog.add_slider(table, 
+        self.config_meeting_slider = configdialog.add_slider(grid,
                 "", 
                 2, 'geography.maximum_meeting_zone',
                 (1, 9))
-        return _('The selection parameters'), table
+        return _('The selection parameters'), grid
 
     def config_connect(self):
         """
